from typing import Any, Dict, List, Text, Union


class DataConverter:
    def __init__(self, language: Text):
        self.language = language

    @staticmethod
    def training_data_converter(final_data) -> List[Union[Text, Dict[Text]]]:
        NotImplementedError("Training data converter is not implemented")

    def regex_converter(
        self, final_data
    ) -> List[Dict[str, Union[Union[str, List[Any]], Any]]]:
        NotImplementedError("Regex converter is not implemented")

    def synonym_converter(
        self, final_data
    ) -> List[Dict[str, Union[Union[str, List[Any]], Any]]]:
        NotImplementedError("synonym converter is not implemented")

    def lookup_converter(self, final_data):
        NotImplementedError("lookup converter is not implemented")



import json
from pathlib import Path

from rasa.nlu.convert import convert_training_data

cvt = convert_training_data(
    "../../data/Online-Shopping", "./nlu.json", "json", language="en"
)

with open(Path("./nlu.json")) as f:
    data = json.load(f)

final_data = data["rasa_nlu_data"]

with open(Path("./dialog_to_ns.json"), "w") as f:
    json.dump(final_data, f, indent=4)

print(final_data)

#  ----  regex  ----
# list_of_values = []
# regex_entity = []
# language = "en"
# for values in final_data['regex_features']:
#     if values['name'] not in list_of_values:
#         list_of_values.append(values['name'])
#         regex_entity.append({"entity": values['name'],
#                              "examples": [],
#                              "language": language,
#                              "entityType": "regex"})
#     index = list_of_values.index(values['name'])
#     regex_entity[index]["examples"].append(values['pattern'])
# print("\n\n\n\n\n")
# print(regex_entity)

# lookups

# list_of_lookup = []
# language = "en"
# for values in final_data['lookup_tables']:
#     values['entity'] = values.pop('name')
#     values['examples'] = values.pop('elements')
#     values['language'] = language
#     values['entityType'] = "lookup"
#     list_of_lookup.append(values)
#
# print('\n\n\n\n\n')
# print(list_of_lookup)

# ---- synonyms ----
#
# language = "en"
# list_of_synonyms = []
# for values in final_data['entity_synonyms']:
#     values['entity'] = values.pop('value')
#     values['examples'] = values.pop('synonyms')
#     values['language'] = language
#     values['entityType'] = "synonym"



from rasa.shared.importers.utils import training_data_from_paths

data = training_data_from_paths(["example_rasa_bot/data/nlu.yml"], language="en")
examples = []
entity = []

for ex in data.nlu_examples:
    examples.append(ex.as_dict())


# -- lookup --
# lookup = data.lookup_tables
# list_of_lookups = []
# language = "en"
# for value in lookup:
#     value['entity'] = value.pop('name')
#     value['examples'] = value.pop('elements')
#     value['language'] = language
#     value['entityType'] = "lookup"
#     list_of_lookups.append(value)
# print(list_of_lookups)


# -- regex --
# regex = data.regex_features
# language = "en"
# list_of_regex = []
# list_of_values = []
# for value in regex:
#     if value['name'] not in list_of_values:
#         list_of_values.append(value['name'])
#         value['entity'] = value.pop('name')
#         value['examples'] = [value.pop('pattern')]
#         value['language'] = language
#         value['entityType'] = "regex"
#         list_of_regex.append(value)
#     else:
#         index = list_of_values.index(value['name'])
#         list_of_regex[index]['examples'].append(value['pattern'])


# -- synonym --
# synonyms = data.entity_synonyms
# keys = list(synonyms.keys())
# print(synonyms.values())
# language = "en"
# list_of_synonyms = []
# list_of_values = []
# for value, key in zip(synonyms.values(), list(synonyms.keys())):
#     if value not in list_of_values:
#         list_of_values.append(value)
#         list_of_synonyms.append({"entity": value,
#                                  "examples": [],
#                                  "language": language,
#                                  "entityType": "synonym"})
#
#     index = list_of_values.index(value)
#     list_of_synonyms[index]["examples"].append(key)
# print(list_of_synonyms)


# #
# entitity = data.regex_features
# print(entitity)
#
# with open("./converted_dataset/rasa_to_ns.json", 'w') as f:
#     json.dump(
#         examples, f, indent=4
#     )
# with open("./converted_dataset/entity.json", 'w') as f:
#     json.dump(
#         entitity, f, indent=4
#     )

# cvt = convert_training_data('../../data/sample', "./nlu.json", 'json', language='en')
